nu1 = -1;
nu2 = 1;
nu = linspace(-1,1,1001)*5;
k = 0.1;
lw = 0.1;

a = lw - 1i*(nu1-nu);
b = lw - 1i*(nu2-nu);
Z = ((a+b)/2+2*k)./(a.*b+k*(a+b));
Z = ((a+2*k)/2+(b+2*k)/2)./((a+k).*(b+k)-k^2);
Z = real(Z);
plot(nu,Z);


%%
% Determining an optimum truncation window width
% as a function of dnu, k and lw.
%
% The Bloch/McConnell line shape depends on only two parameters:
% lw/dnu and k/dnu.
% We want to find a (heuristic) expression that determines a
% minimal window width as a function of lw/dnu and k/dnu such that
% the intensity (relative to the spectral maximum) at the window
% limits is not greater than a given threshold.
clear
nu1 = 1;
nu2 = -1;
dnu = abs(nu1-nu2);

k = 10.^linspace(-1,1,11)*dnu;
lw = 10.^linspace(-1,1,201)*dnu;

q = zeros(numel(lw),numel(k));
for ilw = 1:numel(lw)
  d(ilw) = max(10*lw(ilw),5*dnu);
  numin = min([nu1 nu2]) - d(ilw);
  numax = max([nu1 nu2]) + d(ilw);
  nu = linspace(numin,numax,10001);
  for ik=1:numel(k)
    a = lw(ilw) - 1i*(nu1-nu);
    b = lw(ilw) - 1i*(nu2-nu);
    Z = ((a+b)/2+2*k(ik))./(a.*b+k(ik)*(a+b));
    Z = real(Z);
    q(ilw,ik) = Z(1)/max(Z);
  end
end
subplot(2,1,1);
semilogx(lw/dnu,q);
xlabel('lw/dnu');
ylabel('wing value');
subplot(2,1,2);
loglog(lw/dnu,d/dnu);
xlabel('lw/dnu');

%%
clear,clf
nu1 = 1;
nu2 = -1;
dnu = abs(nu1-nu2);
lw = 0.0001*dnu;
nu = linspace(0,1,501)*max(dnu*10,lw*50);

k = 10.^linspace(-3,3,301)*dnu;
for ik = 1:numel(k)
  c = 10;
  k_ = k(ik);
  if (k_/dnu)>1, d(ik) = c*(4*lw+1/k_);
  elseif (k_/dnu)<0.2, d(ik) = c*(4*lw+k_)+dnu/2;
  else d(ik) = c*(4*lw+1/dnu); end
  a = lw + 1i*(nu-nu1);
  b = lw + 1i*(nu-nu2);
  Z_ = ((a+b)/2+2*k(ik))./(a.*b+k(ik)*(a+b));
  Z(ik,:) = real(Z_)/max(real(Z_));
end
contour(nu/dnu,log10(k/dnu),Z,10.^[0 -1 -2 -3]);
xlabel('nu/dnu offset');
ylabel('log10(k/dnu)');
text(mean(xlim),mean(ylim),sprintf('lw/dnu = %g',lw/dnu));
hold on
plot(d/dnu,log10(k/dnu),'r.');


