
%% Dinitrodurene anion radical
% Freed/Fraenkel, J.Chem.Phys. 37 1156 (1962)
% Weil/Bolton 2007, p.333
clear

Sys.A(1,:) = [20 10 1];
Sys.A(2,:) = [10 20 1];
Sys.Nucs = '14N,14N,1H';
Sys.n = [1 1 12];
Sys.lwpp = 0.015;
Sys.k = 50;
Exp.nPoints = 2048;
%Opt.Output = 'separate';
Opt.Method = -1;
exchange(Sys,Exp,Opt);
ylim([-1 1]*0.5);

%% Dinitromesitylene anion radical
% Telo/Jalilov/Nelson J.Phys.Chem.A 115 3016 (2011), Fig.5
clear

Sys.Nucs = '14N,14N,1H,1H,1H,1H';
Sys.n = [1 1 3 3 3 1];
Sys.A(1,:) = [15.85 0 1.41 1.41 1.04 1.11]*2.8;
Sys.xc = [2 1 3 5 4 6];
Sys.lwpp = 0.0120;
Sys.k = 500; % us^-1 = 10^6 s^-1

exchange(Sys);

%% Thiothiophten radical
% Heinzer, Mol.Phys. 22, 167-177 (1971), Fig. 1

clear
Sys.Nucs = '1H,1H,1H,1H,1H,1H';
Sys.n = [2 2 2 2 1 1];
Sys.A = [4.01 3.47 2.92 1.16 0.50 0.04]*2.8;
Sys.xc = [2 1 4 3 6 5];
Sys.lwpp = 0.028;     % mT

Exp.mwFreq = 9.5;
Exp.Range = [337.5 340.5];

Sys.k = 1.761e-2; [x,y1] = exchange(Sys,Exp);
Sys.k = 1.813e1; [x,y2] = exchange(Sys,Exp);
Sys.k = 1.761e4; [x,y3] = exchange(Sys,Exp);

y2 = rescale(y2,y1);
y3 = rescale(y3,y1);

shift = -1.7*max(abs(y1));
plot(x,y1,x,y2+shift,x,y3+2*shift);

%% Cyclooctatetraene radical anion
% Stevenson/Kim, J.Am.Chem.Soc. 122, 3211-3215 (2000)
% Fig. 3
clear
Sys.Nucs = '1H,1H,1H,1H,1H,1H';
Sys.A(1,:) = [2.46 3.24 1.96 3.03 1.96 3.36]*2.8;
Sys.xc = [6 5 4 3 2 1];
Sys.k = 30; % us^-1
Sys.lw = 0.01; % mT
tic
exchange(Sys);
toc

