%% Field range
clear, clc

Sys.g = [2.001 2.001];
Sys.A(1,:) = [30];
Sys.A(2,:) = [5];
Sys.Nucs = '1H';
Sys.lwpp = 0.05; % mT
Sys.k = 1; % us^-1
Exp.Harmonic = 0;
Exp.nPoints = 1e4;
Exp.Range = [330 345]+4;
[x0,y0] = exchange(Sys,Exp); 
Exp.Range = [330 346];
[x1,y1] = exchange(Sys,Exp);
Exp.Range = [];
[x2,y2] = exchange(Sys,Exp);

shift = max(y0)*0.02;
plot(x0,y0,x1,y1+shift,x2,y2+2*shift);

%% Mutual exchange syntax
clear, clc
Sys.Nucs = '1H,1H';
Sys.lwpp = 0.02;
Sys.k = 2;

Exp.Harmonic = 0;
Opt.Output = 'separate';

Sys.A = [20 4; 4 20];
[x1,y1] = exchange(Sys,Exp,Opt);

Sys.A(2,:) = [];
Sys.xc = [2 1];
[x2,y2] = exchange(Sys,Exp,Opt);

plot(x1,y1,x2,-y2);

%% Test case two halves
clear, clc
Sys.Nucs = '1H,1H';
Sys.A(1,:) = [20  0];
Sys.A(2,:) = [ 0 20];
Sys.k = 1000;
Sys.lwpp = 0.02;
Exp.mwFreq = 9.5;
Opt.Method = 2;
[x1,y1] = exchange(Sys,Exp,Opt);
%Opt.Method = -2;
%[x2,y2] = exchange(Sys,Exp,Opt);
%plot(x1,y1,x2,y2,'r');
plot(x1,y1);


%% Exchange rate coalescence point test
clear,clc,clf

Sys.g = [2.0 2.01];
Sys.lwpp = 1e-12;

Exp.Harmonic = 2;
Exp.nPoints = 1e5;
Exp.mwFreq = 9.5;

g0 = mean(Sys.g);
B0 = mhz2mt(Exp.mwFreq*1e3,g0);
Exp.Range = B0+[-1 1]*4;

nu = mt2mhz(B0,Sys.g);
dnu = abs(diff(nu));
k_coalescence = (2*pi*dnu/2)/sqrt(2); % in the lw=0 limit
Sys.k = k_coalescence;

[x,y] = exchange(Sys,Exp);
plot(x,y,B0,0,'r+');

%% Linewidth coalescence point test
clear,clc,clf

Sys.g = [2.0 2.01];
Sys.k = 0;

Exp.mwFreq = 9.5;
g0 = mean(Sys.g);
B0 = mhz2mt(Exp.mwFreq*1e3,g0);
Exp.Range = B0+[-1 1]*8;

nu = mt2mhz(B0,Sys.g);
dnu = abs(diff(nu));

% theoretical coalescence value for Gamma (=1/T2), assuming k=0
% (frequency domain)
Gamma_coalescence = (2*pi*dnu/2)*sqrt(3);
% conversion of Gamma to Lorentzian peak-to-peak linewidth
% (still frequency domain)
lwpp_coalescence = Gamma_coalescence/pi/sqrt(3);
% frequency to field conversion
Sys.lwpp = mhz2mt(lwpp_coalescence,mean(Sys.g));

Exp.mwFreq = 9.5;
Exp.Harmonic = 2;
Exp.nPoints = 1e5+1;

exchange(Sys,Exp);
[x,y] = exchange(Sys,Exp);
plot(x,y,B0,0,'r+');

%% Test case two g values without nuclei
clear,clc,clf
Sys.g = [2.0 2.01];
Sys.k = 11.40064;
Sys.lwpp = 0.1;
Exp.mwFreq = 9.5;
Exp.Harmonic = 1;
Exp.nPoints = 30000;
Exp.Range = [334 343];
exchange(Sys,Exp);
ylim([-1 1]*0.3);

%% Test case one nucleus
clear, clc

Sys.A(1,:) = [1 2]*28;
Sys.Nucs = '14N';
Sys.lwpp = 0.05;
Sys.k = 50;
Exp.Range = 338.98+[-1 1]*6;
Exp.Harmonic = 1;
Exp.nPoints = 1e5;
Opt.Method = -1;
exchange(Sys,Exp,Opt);
