/*
 * spc = exlinesum2(k,Gamma,numean,delta2,intensity,nux)
 *
 *   k          exchange rate constant, us^-1
 *   Gamma      1/T2, us^-1
 *   numean     average line position (nu1+nu2)/2, MHz
 *   delta2     ((nu1-nu2)/2)^2, MHz^2
 *   intensity  intensity of line pair, arb.u.
 *   nux        frequency abscissa, MHz
 *
 *   spc        output spectrum
 */

#include <mex.h>

void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
{

  /* input parameters */
  double k, Gamma, *numean, *delta2, *intensity, *nux;
  /* working variables */
  int nLines, nPoints, idx, iLine;
  double a, c, d, c0, c1, d0, xi;
  double *spc;

  /* Argument checks. */
  if (nrhs!=6) mexErrMsgTxt("Wrong number of input parameters!");
  if (nlhs!=1) mexErrMsgTxt("Wrong number of output parameters!");
    
  /* Get all input arguments. */
  k = mxGetScalar(prhs[0]);
  Gamma = mxGetScalar(prhs[1]);
  numean = mxGetPr(prhs[2]);
  delta2 = mxGetPr(prhs[3]);
  intensity = mxGetPr(prhs[4]);
  nux = mxGetPr(prhs[5]);
  /* Get vector lengths. */
  nLines = (int)mxGetNumberOfElements(prhs[2]);
  if (nLines!=(int)mxGetNumberOfElements(prhs[3]))
    mexErrMsgTxt("numean and delta2 must have the same number of elements!");
  if (nLines!=(int)mxGetNumberOfElements(prhs[4]))
    mexErrMsgTxt("numean and intensity must have the same number of elements!");

  /* allocate results array */
  nPoints = (int)mxGetNumberOfElements(prhs[5]);
  plhs[0] = mxCreateDoubleMatrix(1,nPoints,mxREAL); 
  spc = mxGetPr(plhs[0]);
  
  a = 2*k + Gamma;
  c0 = Gamma*(2*k+Gamma);
  d0 = 2*(k+Gamma);
  for (iLine=0;iLine<nLines;iLine++){
    c1 = c0 + delta2[iLine];
    for (idx=0;idx<nPoints;idx++){
      xi = nux[idx] - numean[iLine];
      c = c1 - xi*xi;
      d = d0*xi;
      spc[idx] += intensity[iLine]*(a*c+xi*d)/(c*c+d*d);
    }
  }

} /* void mexFunction */
